@@ -1,19 +1,21 @@
 from __future__ import annotations
 
-from typing import TYPE_CHECKING, Dict
+from typing import TYPE_CHECKING, Dict, cast
 
-from kubernetes.dynamic.exceptions import ConflictError
+from pydantic import Field
 
-from ..resource import ResourceItem
+from kubernetes_dynamic.models.common import V1ObjectMeta, get_default
+
+from ..exceptions import ConflictError
+from .resource_item import ResourceItem
 
 if TYPE_CHECKING:
-    from . import V1NamespaceSpec, V1NamespaceStatus, V1ObjectMeta
+    from .all import V1NamespaceSpec, V1NamespaceStatus
 
 
 class V1Namespace(ResourceItem):
-    metadata: V1ObjectMeta
-    spec: V1NamespaceSpec
-    status: V1NamespaceStatus
+    spec: V1NamespaceSpec = Field(default_factory=lambda: get_default("V1NamespaceSpec"))
+    status: V1NamespaceStatus = Field(default_factory=lambda: get_default("V1NamespaceStatus"))
 
     def annotate(self, annotations_dict: Dict[str, str]) -> V1Namespace:
         """Add annotation(s) to the namespace."""
@@ -24,7 +26,7 @@ class V1Namespace(ResourceItem):
 
     @classmethod
     def ensure(cls, name: str) -> V1Namespace:
-        item = V1Namespace(metadata={"name": name})
+        item = V1Namespace(metadata=cast(V1ObjectMeta, {"name": name}))
         try:
             return item.create()
         except ConflictError:
